pub fn generate_code(
diesel_schema_file_contents: &str,
config: &GenerationConfig<'_>,
) -> Result<Vec<ParsedTableMacro>>Expand description
Generate a model for the given schema contents
Model is returned and not saved to disk yet
pub fn generate_code(
diesel_schema_file_contents: &str,
config: &GenerationConfig<'_>,
) -> Result<Vec<ParsedTableMacro>>Generate a model for the given schema contents
Model is returned and not saved to disk yet